@@ -13,9 +13,9 @@ except:
 
 from sysam.sysam_3_test import Sysam3Test
 
-from signaux.signal_gbf import GBF
-from signaux.signal_fourier import Fourier
-from signaux.signal_sysam import Sysam
+from signaux.signal_gbf import SignalGBF
+from signaux.signal_fourier import SignalFourier
+from signaux.signal_sysam import SignalSysam
 
 import base.voie_base
 
@@ -83,7 +83,7 @@ if __name__ == "__main__":
     N = 10
     liste_signaux = []
     for i in range(N):
-        liste_signaux.append(GBF(liste_tmin_tmax = liste_tmin_tmax, Te = Te))
+        liste_signaux.append(SignalGBF(liste_tmin_tmax = liste_tmin_tmax, Te = Te))
 
     liste_signaux[0].configurer_voie("EA1")
     liste_signaux[1].configurer_voie("SA1")
